@@ -1,25 +1,19 @@
 from __future__ import annotations
-from ormlambda.sql.clause_info import AggregateFunctionBase
+from ormlambda.sql.clauses import Count
 from ormlambda.sql.clause_info.clause_info_context import ClauseContextType
 
 from ormlambda.sql.types import AliasType, ColumnType
 
 from ormlambda import Table
 
-import typing as tp
+from typing import TYPE_CHECKING
 
-from ormlambda.sql.types import ASTERISK
-
-if tp.TYPE_CHECKING:
+if TYPE_CHECKING:
     from ormlambda import Table
     from ormlambda.sql.types import ColumnType, AliasType, TableType
 
 
-class Count[T: Table](AggregateFunctionBase[T]):
-    @staticmethod
-    def FUNCTION_NAME() -> str:
-        return "COUNT"
-
+class Count[T: Table](Count[T]):
     def __init__[TProp: Table](
         self,
         element: ColumnType[T] | TableType[TProp],
@@ -29,12 +23,8 @@ class Count[T: Table](AggregateFunctionBase[T]):
         keep_asterisk: bool = True,
         preserve_context: bool = True,
     ) -> None:
-        table = self.extract_table(element)
-        column = element if self.is_column(element) else ASTERISK
-
         super().__init__(
-            table=table if (alias_table or (context and table in context._table_context)) else None,
-            column=column,
+            element=element,
             alias_table=alias_table,
             alias_clause=alias_clause,
             context=context,
