@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Any, Callable, Optional, Type, overload, TYPE_CHECKING
 from enum import Enum
-from abc import abstractmethod, ABC
+from abc import abstractmethod
 
 
 if TYPE_CHECKING:
@@ -9,12 +9,11 @@ if TYPE_CHECKING:
     from ormlambda import Table
     from ormlambda.sql.clause_info import IAggregate
     from ormlambda.sql.types import TupleJoinType, ColumnType
-    from ormlambda.components.join import JoinContext
+    from ormlambda.sql.clauses.join import JoinContext
     from ormlambda.common.enums import JoinType
     from ormlambda.sql.clause_info import ClauseInfo
     from ormlambda.sql.types import AliasType
 
-
 from ..types import (
     OrderTypes,
     Tuple,
@@ -31,9 +30,10 @@ from ..types import (
     WhereTypes,
     SelectCols,
 )
+from ormlambda.sql.elements import Element
 
 
-class IStatements[T: Table](ABC):
+class IStatements[T: Table](Element):
     @abstractmethod
     def create_table(self, if_exists: TypeExists = "fail") -> None: ...
 
@@ -334,6 +334,7 @@ class IStatements_two_generic[T, TPool](IStatements[T]):
     def repository(self) -> BaseRepository[TPool]: ...
 
     @property
+    @abstractmethod
     def query(self) -> str: ...
 
     @property
